#####################################################################
#
#  (C) Copyright IBM Corp. 2008.
#  All Rights Reserved
#  Licensed Material - Property of IBM
#
#####################################################################

########################################################################
#
# wsadmin -lang jython -f jdbc_config.py 
#         <dbDriverPath> <dbUser> <dbPass> <dbName> <dbPort> <hostname>
#
########################################################################

import sys
def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

dbDriverPath = sys.argv[0]
dbUser = sys.argv[1]
dbPass = sys.argv[2]
dbName = sys.argv[3]
dbPort = sys.argv[4]
hostname = sys.argv[5]

print "Starting jdbc_config.py....\n"
print "jdbc_config.py " + dbDriverPath + " " + dbUser + " ****** " + dbName + " " + dbPort + " " + hostname + "\n\n"


#######################################################################
#
#  Initialize
#
#######################################################################

#Define the implementation class
dbImpClass = "com.ibm.db2.jcc.DB2ConnectionPoolDataSource"

print "Database Implementation Class=" + dbImpClass + "\n"

#Get Node ID
node = AdminConfig.getid("/Node:DefaultNode/")
print "NodeID=" + node + "\n"

#Get Cell ID
cell = AdminControl.getCell()
print "Cell=" + cell + "\n"

#Get Security ID
securityID = AdminConfig.getid("/Cell:" + cell + "/Security:/")
print "Security=" + securityID + "\n"

#Get Server ID
serverID = AdminConfig.getid("/Server:server1/")
print "ServerID = " + serverID + "\n"

#Get Relational Resource Adapter
rsadapter = AdminConfig.list("J2CResourceAdapter", serverID)
print "Relational Resource Adapter=" + rsadapter + "\n"


########################################################################
#
# Create JAAS Authentication Data Object for Database Alias
#
########################################################################

print "Create JAASAuthData object for alias db2admin\n"
AliasAttrs = [["alias", "db2admin"], ["description", "TPCRM Alias"], ["userId", dbUser], ["password", dbPass]]
authdata = AdminConfig.create("JAASAuthData", securityID, AliasAttrs)
print "JAAS Authentication Data=" + authdata + "\n"


######################################################################
#
# Create JDBC Provider
#
######################################################################

Separator = ':'
if (len(dbDriverPath)>0 and dbDriverPath[1]==':' and dbDriverPath[2]=='/'):
  print 'WINDOWS\n'
  Separator = ';'
else :
  print 'UNIX\n'

ClassPathList = []
ClassPathList.append(dbDriverPath + '/db2jcc.jar')
ClassPathList.append(dbDriverPath + '/db2jcc_license_cu.jar')
ClassPath = Separator.join(ClassPathList)
print "ClassPath = " + ClassPath + "\n"

print "Creating the provider for " + dbImpClass + "\n"
CSMProviderAttrs = [["classpath", ClassPath], ["implementationClassName", dbImpClass], ["name", "CSMProvider"], ["description", "DB2 JDBC Provider"], ["xa", "false"]]
CSMProvider = AdminConfig.create("JDBCProvider", serverID, CSMProviderAttrs)
print "JDBC Provider=" + CSMProvider + "\n"


######################################################################
#
# Creating DataSource CSMDS
#
######################################################################

print "Creating the datasource CSMDS"
CSMDataSourceAttrs = [["name", "CSMDS"], ["description", "TPCRM DataSource"]]
CSMDataSource = AdminConfig.create("DataSource", CSMProvider, CSMDataSourceAttrs)
print "DataSource = " + CSMDataSource + "\n"


######################################################################
#
# Set Database-Related Properties
#
######################################################################

#Set the properties for the data source.
propertySet = AdminConfig.create("J2EEResourcePropertySet", CSMDataSource, [] )

attrs = [["name", "databaseName"], ["type", "java.lang.String"], ["value", dbName]]
AdminConfig.create("J2EEResourceProperty", propertySet, attrs )

attrs = [["name", "driverType"], ["type", "java.lang.Integer"], ["value", 4]]
AdminConfig.create("J2EEResourceProperty", propertySet, attrs )

attrs = [["name", "serverName"], ["type", "java.lang.String"], ["value", hostname]]
AdminConfig.create("J2EEResourceProperty", propertySet, attrs )

attrs = [["name", "portNumber"], ["type", "java.lang.Integer"], ["value", dbPort]]
AdminConfig.create("J2EEResourceProperty", propertySet, attrs )

attrs = [["jndiName", "jdbc/CSMDS"], ["statementCacheSize", 10], ["datasourceHelperClassname", "com.ibm.websphere.rsadapter.DB2DataStoreHelper"], ["relationalResourceAdapter", rsadapter], ["authMechanismPreference", "BASIC_PASSWORD"], ["authDataAlias", "db2admin"]]
AdminConfig.modify(CSMDataSource, attrs)

# Configure the Connection Pool parameters
print "Configuring Connection Pool Settings..."
poolid = AdminConfig.showAttribute(CSMDataSource, "connectionPool")
AdminConfig.modify(poolid, [["maxConnections", 30], ["connectionTimeout", 1800]])
print "Connection Pool Settings Configured."

#######################################################################
#
# Save Configuration
#
#######################################################################

AdminConfig.save()
print "Configuration Saved\n"

